# PulsePoint to TAK Gateway

PulseCOT is a lightweight Python application designed to bridge PulsePoint emergency call data with Team Awareness Kit (TAK) platforms. It enables seamless integration of real-time emergency information into TAK products such as ATAK, WinTAK, and iTAK. With support for both multicast and unicast transmissions, as well as TAK Server compatibility, PulseCOT ensures flexibility in delivering critical data to your TAK ecosystem.

## Example Agencies
- **DC Fire & EMS**: EMS1205

## Call Types Source
[PulsePoint Call Types JSON](https://web.pulsepoint.org/assets/json/call_types.json)

## License
Copyright Sensors & Signals LLC [https://snstac.com/](https://snstac.com/)

Licensed under the Apache License, Version 2.0 (the "License");  
you may not use this file except in compliance with the License.  
You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software  
distributed under the License is distributed on an "AS IS" BASIS,  
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  
See the License for the specific language governing permissions and limitations under the License.
